<a href="{{ url }}" title="{{ name }}" style="font-family: django-cms-iconfont;" class="cms-btn cms-edit-toggle{% if active %} cms-btn-active{% endif %}{% if disabled %} cms-btn-disabled{% endif %}"><span{% if extra_classes %} class="{{ extra_classes|join:' ' }}"{% endif %}></span></a>
